<?php
/**
 * Plugin Name:  BuddyPress Auto Friendship Pro
 * Version:      1.2.5
 * Plugin URI:   https://buddydev.com/plugins/buddypress-auto-friendship-pro/
 * Description:  This plugin allows site-admin to create different friendships and auto friend with the use who met with the friendship conditions.
 * Author:       BuddyDev
 * Author URI:   https://buddydev.com/
 * Requires PHP: 5.6
 * License:      GPL2
 * License URI:  https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:  buddypress-auto-friendship-pro
 * Domain Path:  /languages
 *
 * @package buddypress-auto-friendship-pro
 **/

use BuddyPress_Auto_Friendship_Pro\Bootstrap\Autoloader;
use BuddyPress_Auto_Friendship_Pro\Bootstrap\Bootstrapper;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Class BP_Auto_Friendship_Pro
 *
 * @property-read string $path Absolute path to the plugin directory.
 * @property-read string $url  Absolute url to the plugin directory.
 * @property-read string $basename Plugin base name.
 * @property-read string $version Plugin version.
 */
class BP_Auto_Friendship_Pro {

	/**
	 * Plugin Version.
	 *
	 * @var string
	 */
	private $version = '1.2.5';

	/**
	 * Class instance
	 *
	 * @var BP_Auto_Friendship_Pro
	 */
	private static $instance = null;

	/**
	 * Plugin absolute directory path
	 *
	 * @var string
	 */
	private $path;

	/**
	 * Plugin absolute directory url
	 *
	 * @var string
	 */
	private $url;

	/**
	 * Plugin Basename.
	 *
	 * @var string
	 */
	private $basename;

	/**
	 * Protected properties. These properties are inaccessible via magic method.
	 *
	 * @var array
	 */
	private $guarded = array( 'instance' );

	/**
	 * BuddyPress_Auto_Friendship_Pro constructor.
	 */
	private function __construct() {
		$this->bootstrap();
	}

	/**
	 * Get Singleton Instance
	 *
	 * @return BP_Auto_Friendship_Pro
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Bootstrap the core.
	 */
	private function bootstrap() {
		$this->path     = plugin_dir_path( __FILE__ );
		$this->url      = plugin_dir_url( __FILE__ );
		$this->basename = plugin_basename( __FILE__ );

		// Load autoloader.
		require_once $this->path . 'src/bootstrap/class-autoloader.php';

		$autoloader = new Autoloader( 'BuddyPress_Auto_Friendship_Pro\\', __DIR__ . '/src/' );

		spl_autoload_register( $autoloader );

		// Drop tables on uninstall.
		// register_uninstall_hook( __FILE__, array( 'Schema', 'drop' ) );.

		Bootstrapper::boot();
	}

	/**
	 * Magic method for accessing property as readonly(It's a lie, references can be updated).
	 *
	 * @param string $name property name.
	 *
	 * @return mixed|null
	 */
	public function __get( $name ) {

		if ( ! in_array( $name, $this->guarded, true ) && property_exists( $this, $name ) ) {
			return $this->{$name};
		}

		return null;
	}
}

/**
 * Helper to access singleton instance
 *
 * @return BP_Auto_Friendship_Pro
 */
function bp_auto_friendship_pro() {
	return BP_Auto_Friendship_Pro::get_instance();
}

bp_auto_friendship_pro();
