<?php
/**
 * BuddyPress Auto Friendship Pro Admin Filters
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Admin
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Admin;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class BPAFP_Admin_Filters
 */
class BPAFP_Admin_Filters {

	/**
	 * List members
	 *
	 * @var array
	 */
	private $list_members = array();

	/**
	 * Class bootstrapper
	 */
	public static function boot() {
		$self = new self();

		$self->setup();
	}

	/**
	 * Other class initialization
	 */
	private function setup() {
		add_filter( 'manage_posts_columns', array( $this, 'modify_columns' ), 10, 2 );
		add_action( 'manage_posts_custom_column', array( $this, 'render_column_data' ), 10, 2 );

		// Added sortable column.
		add_filter( 'manage_edit-' . bpafp_get_list_post_type() . '_sortable_columns', array( $this, 'modify_sortable_columns' ) );
		add_action( 'pre_get_posts', array( $this, 'handle_orderby' ) );
	}

	/**
	 * Modify columns
	 *
	 * @param array  $posts_columns Post columns.
	 * @param string $post_type Post type.
	 *
	 * @return array
	 */
	public function modify_columns( $posts_columns, $post_type ) {

		if ( bpafp_get_list_post_type() !== $post_type ) {
			return $posts_columns;
		}

		$posts_columns['list_type'] = __( 'List Type', 'buddypress-auto-friendship-pro' );

		// Reorder date column.
		if ( isset( $posts_columns['date'] ) ) {
			unset( $posts_columns['date'] );

			$posts_columns['date'] = __( 'Date', 'buddypress-auto-friendship-pro' );
		}

		return $posts_columns;
	}

	/**
	 * Sortable columns
	 *
	 * @param array $sortable_columns Sortable columns.
	 *
	 * @return array
	 */
	public function modify_sortable_columns( $sortable_columns ) {
		$sortable_columns['list_type'] = 'list_type';

		return $sortable_columns;
	}

	/**
	 * Handler order by
	 *
	 * @param \WP_Query $query Query object.
	 */
	public function handle_orderby( $query ) {

		if ( ! is_admin() ) {
			return;
		}

		if ( bpafp_get_list_post_type() !== $query->get( 'post_type' ) ) {
			return;
		}

		$orderby = $query->get( 'orderby' );

		if ( 'list_type' === $orderby ) {
			$query->set( 'meta_key', '_bpafp_list_type' );
			$query->set( 'orderby', 'meta_value' );
		}
	}

	/**
	 * Render column data
	 *
	 * @param string $column_name Column name.
	 * @param int    $post_id     Post id.
	 */
	public function render_column_data( $column_name, $post_id ) {

		if ( 'list_type' === $column_name ) {
			$list_type = get_post_meta( $post_id, '_bpafp_list_type', true );
			$list_type = $list_type ? ucfirst( $list_type ) : '';

			echo esc_html( $list_type );
		}
	}
}