<?php
/**
 * BuddyPress Auto Friendship Pro Tools Helper
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Admin
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Admin;

use BuddyPress_Auto_Friendship_Pro\Core\Automatic_Friendship_Creator;
use BuddyPress_Auto_Friendship_Pro\Core\Follow_Following\Automatic_Follower_Creator;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class BPAFP_Admin_Tools_Helper
 */
class BPAFP_Admin_Tools_Helper {

	/**
	 * Class bootstrapper
	 */
	public static function boot() {
		$self = new self();

		$self->setup();
	}

	/**
	 * Other class initialization
	 */
	private function setup() {
		add_action( 'admin_menu', array( $this, 'add_menu' ) );
		add_action( 'admin_init', array( $this, 'make_connection' ) );
		//add_action( 'admin_init', array( $this, 'make_connections' ) );
	}

	/**
	 * Add menu
	 */
	public function add_menu() {
		add_management_page(
			__( 'BP Auto Friendship', 'buddypress-auto-friendship-pro' ),
			__( 'BuddyPress Auto Friendship', 'buddypress-auto-friendship-pro' ),
			'import',
			'bp-auto-friendship',
			array( $this, 'render' )
		);
	}

	/**
	 * Render page content
	 */
	public function render() {

		$placeholder = __( 'Type for auto suggestion', 'buddypress-auto-friendship-pro' );

		?>
        <div class="wrap">
            <h1><?php _e( 'BuddyPress Connection Creator', 'buddypress-auto-friendship-pro' ); ?></h1>

            <div class="bpafp-tool-card">
                <h3><?php _e( 'Connect Users', 'buddypress-auto-friendship-pro' ); ?></h3>
            <form method="post" class="bpafp-make-connection-form" name="bpafp-make-connection-form">
                <p class="bpafp-tool-row">
                    <label class="primary" for="bpafp-user-1-selector"><?php _e( 'Select User A:', 'buddypress-auto-friendship-pro' ); ?></label>
                    <input type="text" name="bpafp-user-1-selector-random-name" id="bpafp-user-1-selector" class="bpafp-user-autocomplete" placeholder="<?php echo esc_attr( $placeholder ); ?>">
                    <input type="hidden" name="bpafp-selected-user-id" class="bpafp-selected-user-id">
                </p>
                <p class="bpafp-tool-row">
                    <label class="primary" for="bpafp-user-2-selector"><?php _e( 'Select User B:', 'buddypress-auto-friendship-pro' ); ?></label>
                    <input type="text" id="bpafp-user-2-selector" name="bpafp-user-2-selector-random-name" class="bpafp-user-autocomplete" placeholder="<?php echo esc_attr( $placeholder ); ?>">
                    <input type="hidden" name="bpafp-selected-friend-user-id" class="bpafp-selected-user-id">
                </p>
                <p class="bpafp-tool-row">
                    <label class="primary" for="bpafp-user-connection-type-selector"><?php _e( 'Action:', 'buddypress-auto-friendship-pro' ); ?></label>
                    <select name="bpafp-selected-action" id="bpafp-user-connection-type-selector">
                        <option value="friend" selected><?php _e( 'Add as Friend', 'buddypress-auto-friendship-pro' ); ?></option>
                        <?php if ( bpafp_is_active_follow_following() ) : ?>
                            <option value="follower"><?php _e( 'Follow user A by user B', 'buddypress-auto-friendship-pro' ); ?></option>
                            <option value="following"><?php _e( 'Follow user B by user A', 'buddypress-auto-friendship-pro' ); ?></option>
                        <?php endif; ?>
                </select>
                </p>
                <p class="bpafp-tool-row">
					<?php wp_nonce_field( 'bpafp-make-connection' ); ?>
                    <input type="submit" class="button" name="bpafp-make-connection-btn" value="<?php _e( 'Make Connection', 'buddypress-auto-friendship-pro' ); ?>">
                </p>
            </form>
            </div>
        </div>
        <style>
            .bpafp-tool-card {
                margin-top: 15px;
                max-width: 500px;
                padding: 15px 30px;
                background: #fff;
                box-shadow: 0 0.8px 1.8px rgba(0, 0, 0, 0.035), 0 6px 14px rgba(0, 0, 0, 0.07);
                border-radius: 4px;
            }

            .bpafp-tool-row {
                display: flex;
            }

            .bpafp-tool-row label {
                min-width: 40%;
            }
        </style>
		<?php
	}

	/**
	 * Render page content
	 */
	public function render_old_list() {

		?>
		<div class="wrap">
            <h1><?php _e( 'BuddyPress Auto Friendship Bulk Action', 'buddypress-auto-friendship-pro' ); ?></h1>

			<form method="post" class="bpafp-make-connections-form" name="bpafp-make-connections-form">
				<p>
					<label class="primary"><?php _e( 'Select User:', 'buddypress-auto-friendship-pro' ); ?></label>
                    <input type="text" name="bpafp-selected-user-id" id="bpafp-user-autocomplete">
                    <input type="hidden" name="bpafp-selected-user-id" id="bpafp-selected-user-id">
				</p>
				<p>
					<label class="primary"><?php _e( 'Select List:', 'buddypress-auto-friendship-pro' ); ?></label>
					<?php if ( $lists = $this->get_lists() ) : ?>
						<?php foreach ( $lists as $list ) : ?>
                            <label>
                                <input type="checkbox" name="bpafp-selected-list-ids[]" value="<?php echo esc_attr( $list->ID ); ?>" />
								<?php echo esc_html( $list->post_title ); ?>
                            </label>
						<?php endforeach; ?>
					<?php else : ?>
                    <?php _e( 'No list found. Please create some first', 'buddypress-auto-friendship-pro' ); ?>
				<?php endif; ?>
				</p>
                <p>
                    <label class="primary"><?php _e( 'Action:', 'buddypress-auto-friendship-pro' ); ?></label>
                    <select name="bpafp-selected-action">
                        <option value="friends" selected><?php _e( 'Add as Friends', 'buddypress-auto-friendship-pro' ); ?></option>
                        <option value="followers"><?php _e( 'Add as Follower', 'buddypress-auto-friendship-pro' ); ?></option>
                    </select>
                </p>
                <p>
                    <?php wp_nonce_field( 'bpafp-make-connections' ); ?>
                    <input type="submit" class="button" name="bpafp-submit-btn" value="<?php _e( 'Make Connections', 'buddypress-auto-friendship-pro' ); ?>">
                </p>
			</form>
		</div>
		<?php
	}

	/**
	 * Make connections
	 */
	public function make_connection() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		if ( ! isset( $_POST['bpafp-make-connection-btn'] ) || ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'bpafp-make-connection' ) ) {
			return;
		}

		$user_id        = empty( $_POST['bpafp-selected-user-id'] ) ? 0 : absint( $_POST['bpafp-selected-user-id'] );
		$connection_user_id = empty( $_POST['bpafp-selected-friend-user-id'] ) ? 0 : absint( $_POST['bpafp-selected-friend-user-id'] );
		$selected_action         = empty( $_POST['bpafp-selected-action'] ) ? '' : sanitize_text_field( $_POST['bpafp-selected-action'] );

		if ( ! $user_id || ! $connection_user_id ) {
			$message = __( 'Please make sure user A & user B are selected.', 'buddypress-auto-friendship-pro' );
			$this->add_notice( $message, 'error' );

			return;
		}

		if ( $user_id == $connection_user_id ) {
			$this->add_notice( __( 'Please amke sure to select 2 different users.', 'buddypress-auto-friendship-pro' ), 'error' );
			return;
		}

		$user_1        = get_user_by( 'id', $user_id );
		$user_2 = get_user_by( 'id', $connection_user_id );

		if ( ! $user_1 || ! $user_2 || ! $selected_action ) {
			$message = __( 'Please make sure user A & user B are selected.', 'buddypress-auto-friendship-pro' );
			$this->add_notice( $message, 'error' );
			return;
		}

        $done = false;
		if ( 'follower' === $selected_action ) {
			$done = $this->start_following( $user_id, $connection_user_id );
		} elseif ( 'following' === $selected_action ) {
			$done = $this->start_following( $connection_user_id ,  $user_id );
		} elseif ( 'friend' === $selected_action && ! friends_check_friendship( $user_id, $connection_user_id ) ) {
			$done = friends_add_friend( $user_id, $connection_user_id, true );
		}

		if ( $done ) {
			$this->add_notice( sprintf( __( '%s and %s are connected successfully.', 'buddypress-auto-friendship-pro' ), bp_core_get_user_displayname( $user_id ), bp_core_get_user_displayname( $connection_user_id ) ), 'success' );
		} else {
			$this->add_notice( __( 'There was a problem. Please try again later.', 'buddypress-auto-friendship-pro' ), 'error' );
		}
	}

	private function add_notice( $message, $type = 'success' ) {
		add_action( 'admin_notices', function () use ( $message, $type ) {
			echo "<div class='notice notice-{$type} is-dismissible'><p>" . esc_html( $message ) . '</p></div>';
		} );
	}

	/**
	 * Make connections
	 */
	public function make_connections() {

		if ( ! current_user_can( 'import' ) ) {
			return;
		}

		$post = wp_unslash( $_POST );

		if ( ! isset( $post['bpafp-submit-btn'] ) || ! wp_verify_nonce( $post['_wpnonce'], 'bpafp-make-connections' ) ) {
			return;
		}

		$selected_user_id = empty( $post['bpafp-selected-user-id'] ) ? 0 : absint( $post['bpafp-selected-user-id'] );
		$selected_user    = get_user_by( 'id', $selected_user_id );

		if ( ! $selected_user ) {
			return;
		}

		if ( empty( $post['bpafp-selected-list-ids'] ) ) {
			return;
		}

		$selected_list_ids = array_map( 'absint', $post['bpafp-selected-list-ids'] );
		$selected_action   = $post['bpafp-selected-action'];

		if ( 'followers' === $selected_action ) {
			$this->make_followers( $selected_user_id, $selected_list_ids );
			return;
		} elseif ( 'friends' === $selected_action ) {
			$this->make_friends( $selected_user_id, $selected_list_ids );
		}
	}

	/**
	 * Make followers
	 *
	 * @param int   $user_id User id.
	 * @param int[] $list_ids List ids.
	 */
	private function make_followers( $user_id, $list_ids ) {

		if ( ! bpafp_is_active_follow_following() ) {
			return;
		}

		$lists = array_map( 'get_post', $list_ids );

		Automatic_Follower_Creator::create_followers( $user_id, $lists );
	}

	/**
	 * Start following
	 *
	 * @param int   $leader_id User id.
	 * @param int $follower_id List ids.
	 */
	private function start_following( $leader_id, $follower_id ) {

		if ( ! bpafp_is_active_follow_following() ) {
			return false;
		}

		Automatic_Follower_Creator::boot()->start_following( $leader_id, $follower_id );

        return true;// @todo update.
	}

	/**
	 * Make friends
	 *
	 * @param int   $user_id User id.
	 * @param int[] $list_ids List ids.
	 */
	private function make_friends( $user_id, $list_ids ) {

		$lists = array_map( 'get_post', $list_ids );

		Automatic_Friendship_Creator::create_connections( $user_id, $lists );
	}

	/**
	 * Get lists
	 *
	 * @return array
	 */
	private function get_lists() {
		global $wpdb;

		$query = $wpdb->prepare( "SELECT ID, post_title FROM {$wpdb->posts} WHERE post_status = %s AND post_type = %s", 'publish', bpafp_get_list_post_type() );

		$lists = $wpdb->get_results( $query );

		return $lists ? $lists : array();
	}
}