<?php
/**
 * Upgrader:- Upgrades our database to current version
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Core
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Admin;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class Friendship_Matcher
 */
class V1_Upgrader {

	/**
	 * Upgrades meta to mark existing lists as friends list.
	 */
	public static function upgrade() {

		global $wpdb;
		$post_ids = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM {$wpdb->posts} WHERE post_type=%s", bpafp_get_list_post_type() ) );

		if ( empty( $post_ids ) ) {
			return;
		}

		foreach ( $post_ids as $post_id ) {
			update_post_meta( $post_id, '_bpafp_list_type', 'friends' );
		}

		self::update_db_version();
	}

	/**
	 * Save current db schema version.
	 */
	protected static function update_db_version() {
		update_option( '_bpafp_db_verion', 1 );
	}
}
