<?php
/**
 * Assets Loader
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Bootstrap;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Assets Loader.
 */
class Assets_Loader {

	/**
	 * Data to be send as localized js.
	 *
	 * @var array
	 */
	private $data = array();

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup
	 */
	public function setup() {
		//add_action( 'bp_enqueue_scripts', array( $this, 'load_assets' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_assets' ) );
	}

	/**
	 * Load plugin assets
	 */
	public function load_assets() {
		$this->register();
		$this->enqueue();
	}

	/**
	 * Register assets.
	 */
	public function register() {
		$this->register_vendors();
		$this->register_core();
	}

	/**
	 * Load assets.
	 */
	public function enqueue() {
		wp_enqueue_style( 'bp_auto_friendship_pro_css' );
		wp_enqueue_script( 'bp_auto_friendship_pro_js' );

		wp_localize_script( 'bp_auto_friendship_pro_js', 'BPAFP', $this->data );
	}

	/**
	 * Register vendor scripts.
	 */
	private function register_vendors() {}

	/**
	 * Register core assets.
	 */
	private function register_core() {
		$bpafp   = bp_auto_friendship_pro();
		$url     = $bpafp->url;
		$version = $bpafp->version;

		wp_register_style(
			'bp_auto_friendship_pro_css',
			$url . 'assets/css/bp-auto-friendship-pro.css',
			false,
			$version
		);

		wp_register_script(
			'bp_auto_friendship_pro_js',
			$url . 'assets/js/bp-auto-friendship-pro.js',
			array( 'jquery', 'underscore', 'jquery-ui-autocomplete' ),
			$version
		);

		$this->data = array(
			'nonce'   => wp_create_nonce( 'bpafp-get-members' ),
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
		);
	}
}
