<?php
/**
 * Class for friendship match for user
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Core
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Core;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class Friendship_Matcher
 */
class User_List_Matcher extends Matcher {

	/**
	 * Friendship_Matcher constructor.
	 *
	 * @param int $user_id User need to match.
	 */
	public function __construct( $user_id ) {
		parent::__construct( $user_id );
	}

	/**
	 * Get matching friendships
	 *
	 * @param \WP_Post[] $user_lists lists.
	 *
	 * @return array
	 */
	public function get_matching_list_ids( $user_lists ) {

		if ( ! $user_lists ) {
			return array();
		}

		$matching_lists = array();

		foreach ( $user_lists as $list ) {

			if ( $this->is_match( $list ) ) {
				$matching_lists[] = $list->ID;
			}
		}

		return $matching_lists;
	}

	/**
	 * Check if list matches with user or not
	 *
	 * @param int      $user_id User id.
	 * @param \WP_Post $list    List id.
	 *
	 * @return bool
	 */
	public static function check_if_list_matches( $user_id, $list ) {
		$self = new self( $user_id );

		return $self->is_match( $list );
	}

	/**
	 * Check weather user match all conditions or not
	 *
	 * @param \WP_Post $list List.
	 *
	 * @return bool
	 */
	private function is_match( $list ) {
		return $this->is_list_match( $list );
	}
}
