<?php
/**
 * Follow helper
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Core\Follow_Following
 * @copyright  Copyright (c) 2020, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Core\Follow_Following;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Contains helper functions for follow functionalities.
 */
trait Follow_Helper {

	/**
	 * Check if user already follow or not
	 *
	 * @param int $follower_user_id User id.
	 * @param int $leader_user_id User id to be checked as following.
	 *
	 * @return false
	 */
	private function is_following( $follower_user_id, $leader_user_id ) {
		$is_following = false;

		if ( function_exists( 'bp_follow_is_following' ) ) {
			$is_following = bp_follow_is_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		} elseif ( function_exists( 'bp_is_following' ) ) {
			$is_following = bp_is_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		}

		return $is_following;
	}

	/**
	 * Retrieves user followers.
	 *
	 * @param int $user_id User id.
	 *
	 * @return array
	 */
	private function get_followers( $user_id ) {
		$followers = array();

		if ( function_exists( 'bp_follow_get_followers' ) ) {
			$followers = (array) bp_follow_get_followers( array( 'user_id' => $user_id ) );
		} elseif ( function_exists( 'bp_get_followers' ) ) {
			$followers = (array) bp_get_followers( array( 'user_id' => $user_id )
			);
		}

		return array_filter( $followers );
	}

	/**
	 * Retrieves user followings.
	 *
	 * @param int $user_id User id.
	 *
	 * @return array
	 */
	private function get_followings( $user_id ) {
		$followings = array();

		if ( function_exists( 'bp_follow_get_following' ) ) {
			$followings = (array) bp_follow_get_following( array( 'user_id' => $user_id ) );
		} elseif ( function_exists( 'bp_get_following' ) ) {
			$followings = (array) bp_get_following( array( 'user_id' => $user_id )
			);
		}

		return array_filter( $followings );
	}

	/**
	 * Add user as follower
	 *
	 * @param int $leader_user_id User id to be add as following of user.
	 * @param int $follower_user_id          User id.
	 */
	private function add_follower( $leader_user_id, $follower_user_id ) {

		if ( (int) $leader_user_id === (int) $follower_user_id ) {
			return;
		}

		if ( function_exists( 'bp_follow_start_following' ) ) {
			bp_follow_start_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		} elseif ( function_exists( 'bp_start_following' ) ) {
			bp_start_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		}
	}

	/**
	 * Add user as follower
	 *
	 * @param int $leader_user_id User id to be add as following of user.
	 * @param int $follower_user_id          User id.
	 */
	private function remove_follower( $leader_user_id, $follower_user_id ) {

		if ( function_exists( 'bp_follow_stop_following' ) ) {
			bp_follow_stop_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		} elseif ( function_exists( 'bp_stop_following' ) ) {
			bp_stop_following(
				array(
					'leader_id'   => $leader_user_id,
					'follower_id' => $follower_user_id,
				)
			);
		}
	}
}