<?php
/**
 * Group Admin Settings Pages Helper.
 *
 * @package    BuddyPress_Auto_Friendship_Pro
 * @subpackage Modules\Groups
 * @copyright  Copyright (c) 2022, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyPress_Auto_Friendship_Pro\Modules\Groups;

use Press_Themes\PT_Settings\Page;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Class Group_Admin_Settings
 */
class Group_Admin_Settings {

	/**
	 * Boot settings
	 */
	public static function boot() {
		$self = new self();

		$self->setup();
	}

	/**
	 * Setup settings
	 */
	public function setup() {
		add_action( 'bpafp_admin_settings_page', array( $this, 'add_settings' ) );
	}

	/**
	 * Initialize the admin settings panel and fields
	 *
	 * @param Page $page Page.
	 */
	public function add_settings( $page ) {

		// General settings tab.
		$settings_panel = $page->add_panel( 'group_settings', _x( 'Groups', 'Admin settings panel title', 'buddypress-auto-friendship-pro' ) );

		$section_join = $settings_panel->add_section( 'join_group', _x( 'On Joining Group', 'Admin settings section title', 'buddypress-auto-friendship-pro' ) );

		$fields = array(
			array(
				'name'    => 'group_join_connect_with',
				'label'   => _x( 'Connect With', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'On joining group, the new user will be connected with specified members of the group if selected.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_group_get_connect_with_options(),
				'default' => array(),
			),
			array(
				'name'    => 'group_join_connection_types',
				'label'   => _x( 'Connection Types', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'On joining group, the new user will be connected as specified above, with selected members of the group.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_get_available_connection_type_options(),
				'default' => array( 'friend' => 'friend' ),
			),
		);

		$section_join->add_fields( $fields );

		$section_leave = $settings_panel->add_section( 'leave_group', _x( 'On Leaving Group', 'Admin settings section title', 'buddypress-auto-friendship-pro' ) );

		$fields = array(
			array(
				'name'    => 'group_leave_connect_with',
				'label'   => _x( 'Disconnect With', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'On leaving group, the user will be disconnected from selected members of the group.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_group_get_connect_with_options(),
				'default' => array(),
			),
			array(
				'name'    => 'group_leave_connection_types',
				'label'   => _x( 'Connection Types', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'On leaving group, user will be disconnected as selected above, with the selected members of the group.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_get_available_connection_type_options( 'removal' ),
				'default' => array( 'friend' => 'friend' ),
			),
		);

		$section_leave->add_fields( $fields );

		$section_remove = $settings_panel->add_section( 'remove_group', _x( 'On Removal From Group', 'Admin settings section title', 'buddypress-auto-friendship-pro' ) );

		$fields = array(
			array(
				'name'    => 'group_remove_connect_with',
				'label'   => _x( 'Disconnect With', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'When a user is removed from a group, they will be disconnected with the selected group members.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_group_get_connect_with_options(),
				'default' => array(),
			),
			array(
				'name'    => 'group_remove_connection_types',
				'label'   => _x( 'Connection Types', 'Admin settings', 'buddypress-auto-friendship-pro' ),
				'desc'    => __( 'When a user is removed from a group, they will be disconnected as selected above, with the selected members of the group.', 'buddypress-auto-friendship-pro' ),
				'type'    => 'multicheck',
				'options' => bpafp_get_available_connection_type_options( 'removal' ),
				'default' => array( 'friend' => 'friend' ),
			),
		);

		$section_remove->add_fields( $fields );
	}
}
